@@ -42,11 +42,11 @@ def supertrend(df,atr_periodsuper,factorsuper):
     if super1==True and super3==False and super4==False and super5==False and super6==False:
         seniales="Compra"
 
-    elif super1==True or super2==True or super3==True or super4==True or super5==True or super6==True or super7==True or super8==True or super9==True or super10==True:
-        seniales="EN COMPRA"
+    elif super1==True or super2==True or super3==True or super4==True:
+        seniales="Compra"
 
-    elif super1==False or super2==False  or super3==False or super4==False or super5==False or super6==False or super7==False or super8==False or super9==False or super10==False:
-        seniales="EN VENTA"
+    elif super1==False or super2==False  or super3==False or super4==False:
+        seniales="Venta"
 
     elif super1==False and super3==True and super4==True and super5==True and super6==True:
         seniales="Venta"
